@@ -47,38 +47,98 @@
 
 #include <math.h>
 
+#ifndef J2000
 #define J2000       2451545.0
+#endif
 #define ERRMSG_SIZE 1024
 
+#ifndef STELLAR_DAY
 #define STELLAR_DAY        86164.098903691
+#endif
+#ifndef TRACKRATE_SIDEREAL
 #define TRACKRATE_SIDEREAL ((360.0 * 3600.0) / STELLAR_DAY)
+#endif
+#ifndef SOLAR_DAY
 #define SOLAR_DAY          86400
+#endif
+#ifndef TRACKRATE_SOLAR
 #define TRACKRATE_SOLAR    ((360.0 * 3600.0) / SOLAR_DAY)
+#endif
+#ifndef TRACKRATE_LUNAR
 #define TRACKRATE_LUNAR    14.511415
+#endif
+#ifndef EARTHRADIUSEQUATORIAL
 #define EARTHRADIUSEQUATORIAL 6378137.0
+#endif
+#ifndef EARTHRADIUSPOLAR
 #define EARTHRADIUSPOLAR 6356752.0
+#endif
+#ifndef EARTHRADIUSMEAN
 #define EARTHRADIUSMEAN 6372797.0
+#endif
+#ifndef SUNMASS
 #define SUNMASS 1.98847E+30
+#endif
+#ifndef PLANK_H
 #define PLANK_H 6.62607015E-34
+#endif
+#ifndef DIRAC_H
 #define DIRAC_H (PLANK_H/(2*M_PI))
+#endif
+#ifndef EINSTEIN_G
 #define EINSTEIN_G 6.67408E-11
+#endif
+#ifndef EULER
 #define EULER 2.71828182845904523536028747135266249775724709369995
+#endif
+#ifndef ROOT2
 #define ROOT2 1.41421356237309504880168872420969807856967187537694
+#endif
+#ifndef AIRY
 #define AIRY 1.21966
+#endif
+#ifndef CIRCLE_DEG
 #define CIRCLE_DEG 360
+#endif
+#ifndef CIRCLE_AM
 #define CIRCLE_AM (CIRCLE_DEG * 60)
+#endif
+#ifndef CIRCLE_AS
 #define CIRCLE_AS (CIRCLE_AM * 60)
+#endif
+#ifndef RAD_AS
 #define RAD_AS (CIRCLE_AS/(M_PI*2))
+#endif
+#ifndef ASTRONOMICALUNIT
 #define ASTRONOMICALUNIT 1.495978707E+11
+#endif
+#ifndef PARSEC
 #define PARSEC (ASTRONOMICALUNIT*RAD_AS)
+#endif
+#ifndef LIGHTSPEED
 #define LIGHTSPEED 299792458.0
+#endif
+#ifndef JULIAN_LY
 #define JULIAN_LY (LIGHTSPEED * SOLAR_DAY * 365)
+#endif
+#ifndef STELLAR_LY
 #define STELLAR_LY (LIGHTSPEED * STELLAR_DAY * 365)
+#endif
+#ifndef FLUX
 #define FLUX(wavelength) (wavelength/(PLANK_H*LIGHTSPEED))
+#endif
+#ifndef CANDLE
 #define CANDLE ((1.0/683.0)*FLUX(555))
+#endif
+#ifndef LUMEN
 #define LUMEN(wavelength) (CANDLE/(4*M_PI)*pow((FLUX(wavelength)/FLUX(555)), 0.25))
+#endif
+#ifndef REDSHIFT
 #define REDSHIFT(wavelength, reference) (1.0-(reference/wavelength))
+#endif
+#ifndef DOPPLER
 #define DOPPLER(shift, speed) (speed*shift)
+#endif
 
 extern const char *Direction[];
 extern const char *SolarSystem[];
@@ -123,6 +183,21 @@ extern "C" {
 */
 int tty_read(int fd, char *buf, int nbytes, int timeout, int *nbytes_read);
 
+/** \brief read buffer from terminal with a delimiter
+    \param fd file descriptor
+    \param buf pointer to store data. Must be initilized and big enough to hold data.
+    \param stop_char if the function encounters \e stop_char then it stops reading and returns the buffer.
+    \param timeout_seconds number of seconds to wait for terminal before a timeout error is issued.
+
+    (Total time = timeout_seconds + timeout_microseconds)
+    \param timeout_microseconds number of microseconds to wait for terminal before a timeout error is issued.
+
+    (Total time = timeout_seconds + timeout_microseconds)
+    \param nbytes_read the number of bytes read.
+    \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
+*/
+int tty_read_expanded(int fd, char *buf, int nbytes, long timeout_seconds, long timeout_microseconds, int *nbytes_read);
+
 /** \brief read buffer from terminal with a delimiter
     \param fd file descriptor
     \param buf pointer to store data. Must be initilized and big enough to hold data.
@@ -131,9 +206,25 @@ int tty_read(int fd, char *buf, int nbytes, int timeout, int *nbytes_read);
     \param nbytes_read the number of bytes read.
     \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
 */
-
 int tty_read_section(int fd, char *buf, char stop_char, int timeout, int *nbytes_read);
 
+/** \brief read buffer from terminal with a delimiter
+    \param fd file descriptor
+    \param buf pointer to store data. Must be initilized and big enough to hold data.
+    \param stop_char if the function encounters \e stop_char then it stops reading and returns the buffer.
+    \param nsize size of buf. If stop character is not encountered before nsize, the function aborts.
+    \param timeout_seconds number of seconds to wait for terminal before a timeout error is issued.
+
+    (Total Timeout is timeout_seconds + timeout_microseconds)
+    \param timeout_microseconds number of microseconds to wait for terminal before a timeout error is issued.
+
+    (Total Timeout  is timeout_seconds + timeout_microseconds)
+    \param nbytes_read the number of bytes read.
+    \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
+*/
+int tty_read_section_expanded(int fd, char *buf, char stop_char, long timeout_seconds, long timeout_microseconds,
+                              int *nbytes_read);
+
 /** \brief read buffer from terminal with a delimiter
     \param fd file descriptor
     \param buf pointer to store data. Must be initilized and big enough to hold data.
@@ -143,7 +234,6 @@ int tty_read_section(int fd, char *buf, char stop_char, int timeout, int *nbytes
     \param nbytes_read the number of bytes read.
     \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
 */
-
 int tty_nread_section(int fd, char *buf, int nsize, char stop_char, int timeout, int *nbytes_read);
 
 /** \brief Writes a buffer to fd.
@@ -173,7 +263,6 @@ int tty_write_string(int fd, const char *buffer, int *nbytes_written);
     \return On success, it returns TTY_OK, otherwise, a TTY_ERROR code.
     \author Wildi Markus
 */
-
 int tty_connect(const char *device, int bit_rate, int word_size, int parity, int stop_bits, int *fd);
 
 /** \brief Closes a tty connection and flushes the bus.
@@ -201,6 +290,9 @@ void tty_clr_trailing_read_lf(int enabled);
 int tty_timeout(int fd, int timeout);
 /*@}*/
 
+int tty_timeout_microseconds(int fd, long timeout_seconds, long timeout_microseconds);
+/*@}*/
+
 /**
  * \defgroup convertFunctions Formatting Functions: Functions to perform handy formatting and conversion routines.
  */
